==> ui-framework-4.6.2-sources.jar: io/intino/alexandria/ui/displays/items/SearchBox1Mold.java <==
package io.intino.alexandria.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class SearchBox1Mold extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, io.intino.alexandria.ui.documentation.Person, UiFrameworkBox> {
	public FirstName1 firstName1;
	public Seabox_16_7_01633428737 seabox_16_7_01633428737;
	public SearchBox1Mold.Seabox_16_7_01633428737. Gender1 gender1;
	public SearchBox1Mold.Seabox_16_7_01633428737. Age1 age1;

    public SearchBox1Mold(UiFrameworkBox box) {
        super(box);
        id("a214424018");
    }

    @Override
	public void init() {
		super.init();
		if (firstName1 == null) firstName1 = register(new FirstName1(box()).<FirstName1>id("a470861507").owner(SearchBox1Mold.this));
		if (seabox_16_7_01633428737 == null) seabox_16_7_01633428737 = register(new Seabox_16_7_01633428737(box()).<Seabox_16_7_01633428737>id("a2093221770").owner(SearchBox1Mold.this));
		if (seabox_16_7_01633428737 != null) gender1 = seabox_16_7_01633428737.gender1;
		if (seabox_16_7_01633428737 != null) age1 = seabox_16_7_01633428737.age1;
	}

	public class FirstName1 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

		public FirstName1(UiFrameworkBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
		}
	}

	public class Seabox_16_7_01633428737 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UiFrameworkBox>  {
		public SearchBox1Mold.Seabox_16_7_01633428737. Gender1 gender1;
		public SearchBox1Mold.Seabox_16_7_01633428737. Age1 age1;

		public Seabox_16_7_01633428737(UiFrameworkBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (gender1 == null) gender1 = register(new Gender1(box()).<Gender1>id("a614608842").owner(SearchBox1Mold.this));
			if (age1 == null) age1 = register(new Age1(box()).<Age1>id("a1453365016").owner(SearchBox1Mold.this));
		}

		public class Gender1 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

			public Gender1(UiFrameworkBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}

		public class Age1 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

			public Age1(UiFrameworkBox box) {
				super(box);
				label("age");
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}

==> ui-framework-4.14.2-sources.jar: io/intino/alexandria/ui/displays/items/SearchBox1Mold.java <==
package io.intino.alexandria.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class SearchBox1Mold extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, io.intino.alexandria.ui.documentation.Person, UiFrameworkBox> {
	public FirstName1 firstName1;
	public _16_7_01633428737 _16_7_01633428737;
	public SearchBox1Mold._16_7_01633428737. Gender1 gender1;
	public SearchBox1Mold._16_7_01633428737. Age1 age1;

    public SearchBox1Mold(UiFrameworkBox box) {
        super(box);
        id("a214424018");
    }

    @Override
	public void init() {
		super.init();
		if (firstName1 == null) firstName1 = register(new FirstName1(box()).<FirstName1>id("a470861507").owner(SearchBox1Mold.this));
		if (_16_7_01633428737 == null) _16_7_01633428737 = register(new _16_7_01633428737(box()).<_16_7_01633428737>id("a_1558658714").owner(SearchBox1Mold.this));
		if (_16_7_01633428737 != null) gender1 = _16_7_01633428737.gender1;
		if (_16_7_01633428737 != null) age1 = _16_7_01633428737.age1;
	}

	public class FirstName1 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

		public FirstName1(UiFrameworkBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
		}
	}

	public class _16_7_01633428737 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UiFrameworkBox>  {
		public SearchBox1Mold._16_7_01633428737. Gender1 gender1;
		public SearchBox1Mold._16_7_01633428737. Age1 age1;

		public _16_7_01633428737(UiFrameworkBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (gender1 == null) gender1 = register(new Gender1(box()).<Gender1>id("a614608842").owner(SearchBox1Mold.this));
			if (age1 == null) age1 = register(new Age1(box()).<Age1>id("a1453365016").owner(SearchBox1Mold.this));
		}

		public class Gender1 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

			public Gender1(UiFrameworkBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}

		public class Age1 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

			public Age1(UiFrameworkBox box) {
				super(box);
				label("age");
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}
